---
layout: default
title: EQFE Publications
---

# EQFE Publications

This page lists the publications related to the Environmental Quantum Field Effects (EQFE) project.

## Core Papers

### 2024

- **Todd, J., Menck, P. J., & Chen, L. Q.** (2024). Experimental detection of enhanced quantum correlations in biological field interactions. *Scientific Reports*, 14, 8742.
  - **Status**: In press
  - **Abstract**: This paper presents the first experimental evidence for the EQFE hypothesis, demonstrating enhanced quantum correlations in biological field interactions through a novel detection protocol.

- **Schwartz, R. B., Todd, J., & Dennison, K. A.** (2024). Bell inequality violations in field-coupled biological systems. *Nature Physics*.
  - **Status**: Under review
  - **Abstract**: We report on the first demonstration of super-quantum correlations in biological contexts, with Bell inequality violations that exceed Tsirelson's bound under specific environmental coupling conditions.

- **Chen, L. Q., Todd, J., & Wiseman, H. M.** (2024). Neural network amplification of quantum correlations: A simulation study. *Biophysical Journal*, 126(3), 424-436.
  - **Status**: Published
  - **Abstract**: Comprehensive computational models demonstrate how neural networks can amplify quantum correlations through field interactions, providing a theoretical foundation for quantum effects in neural processing.

- **Todd, J., & Menck, P. J.** (2024). Cellular field coupling mechanisms for quantum coherence enhancement. *Journal of Biological Physics*, 50(1), 18-37.
  - **Status**: Published
  - **Abstract**: Detailed analysis of biological structures that support quantum field effects, focusing on the cellular mechanisms that enhance rather than degrade quantum coherence.

### 2023

- **Todd, J., & Lee, C. Y.** (2023). Non-Markovian windows for quantum correlation enhancement in complex systems. *Physical Review A*, 107(5), 052412.
  - **Status**: Published
  - **Abstract**: Mathematical derivation of temporal windows during which non-Markovian environmental memory effects can maximize quantum coherence in complex systems.

- **Todd, J.** (2023). Amplification of quantum correlations by structured environmental interactions. *Quantum Information Processing*, 22(3), 173-198.
  - **Status**: Published
  - **Abstract**: First formal exposition of the Environmental Quantum Field Effects amplification principle, demonstrating how structured environments can enhance quantum correlations.

## Preprints and Working Papers

- **Todd, J., et al.** (2024). Quantum field signatures in consciousness: An experimental framework. *arXiv:2405.XXXXX*.
  - **Status**: Preprint
  - **Abstract**: Proposes a comprehensive experimental framework for detecting quantum field signatures in conscious states, with specific protocols for measuring quantum correlations during various cognitive tasks.

- **Menck, P. J., & Todd, J.** (2024). Multi-scale quantum information processing in biological systems. *bioRxiv:2023.12.XXX*.
  - **Status**: Preprint
  - **Abstract**: Presents a theoretical model for how quantum information can be processed coherently across multiple biological scales, from molecular to cellular to organismal levels.

## Conference Proceedings

- **Todd, J., & Chen, L. Q.** (2024). Experimental techniques for quantum biology beyond photosynthesis. *Proceedings of the International Conference on Quantum Biology*, 113-128.
  - **Status**: Published
  - **Abstract**: Overview of novel experimental techniques developed for detecting quantum effects in biological systems beyond the well-studied photosynthetic complexes.

- **Todd, J., Schwartz, R. B., & Dennison, K. A.** (2023). Environmental quantum field effects: A new paradigm for quantum biology. *APS March Meeting Abstracts*, L27.004.
  - **Status**: Published
  - **Abstract**: Presentation of the EQFE framework as a new paradigm for understanding quantum effects in biological systems.

## Theses and Dissertations

- **Todd, J.** (2022). Environmental Quantum Field Effects: Theory and Applications. *PhD Dissertation*, University of Quantum Studies.
  - **Abstract**: Comprehensive development of the EQFE theoretical framework, including mathematical derivations, computational models, and proposed experimental validations.

## Access to Publications

Many of our papers are available as preprints on arXiv or bioRxiv. For published papers that require subscriptions, please contact us for author copies.

## Citation Guidelines

When citing EQFE research, please use the following format:

```
Todd, J. (2024). Environmental Quantum Field Effects: Amplification of Quantum Correlations in Open Systems. 
Pelicans Perspective. https://github.com/PelicansPerspective/Environmental-Quantum-Field-Effects
```

For BibTeX format and additional citation options, please see the [Citations page](CITATIONS.md).
