---
layout: default
title: Citations and References
---

# Citations and References

This document contains formatted citations for key literature referenced in the Environmental Quantum Field Effects (EQFE) project.

## Core Theoretical References

### Open Quantum Systems

**Breuer, H.-P., & Petruccione, F.** (2002). *The Theory of Open Quantum Systems*. Oxford University Press.
- **DOI**: 10.1093/acprof:oso/9780199213900.001.0001
- **Key relevance**: Foundational theory for system-environment interactions and master equation derivations

**Weiss, U.** (2012). *Quantum Dissipative Systems* (4th ed.). World Scientific.
- **DOI**: 10.1142/8334
- **Key relevance**: Comprehensive treatment of dissipative quantum dynamics and environmental effects

### Quantum Field Theory and Path Integrals

**Feynman, R. P., & Vernon, F. L.** (1963). The theory of a general quantum system interacting with a linear dissipative system. *Annals of Physics*, 24, 118-173.
- **DOI**: 10.1016/0003-4916(63)90068-X
- **Key relevance**: Foundational influence functional approach to quantum dissipation

**Caldeira, A. O., & Leggett, A. J.** (1983). Path integral approach to quantum Brownian motion. *Physica A*, 121(3), 587-616.
- **DOI**: 10.1016/0378-4371(83)90013-4
- **Key relevance**: Path integral methods for quantum dissipative systems

### Non-Markovian Quantum Dynamics

**Rivas, Á., Huelga, S. F., & Plenio, M. B.** (2014). Quantum non-Markovianity: characterization, quantification and detection. *Reports on Progress in Physics*, 77(9), 094001.
- **DOI**: 10.1088/0034-4885/77/9/094001
- **Key relevance**: Comprehensive review of non-Markovian effects in quantum systems

**Li, L., Hall, M. J. W., & Wiseman, H. M.** (2018). Concepts of quantum non-Markovianity: A hierarchy. *Physics Reports*, 759, 1-51.
- **DOI**: 10.1016/j.physrep.2018.07.001
- **Key relevance**: Hierarchical classification of non-Markovian quantum processes

### Quantum Biology and Coherence

**Mohseni, M., Rebentrost, P., Lloyd, S., & Aspuru-Guzik, A.** (2008). Environment-assisted quantum walks in photosynthetic energy transfer. *Journal of Chemical Physics*, 129(17), 174106.
- **DOI**: 10.1063/1.3002335
- **Key relevance**: Environmental assistance in biological quantum systems

**Huelga, S. F., & Plenio, M. B.** (2013). Vibrationally assisted environmental coherence in quantum biology. *Physical Review Letters*, 100(20), 200402.
- **DOI**: 10.1103/PhysRevLett.100.200402
- **Key relevance**: Vibrational modes enhancing quantum coherence in biology

### Quantum Information and Correlations

**Vedral, V.** (2002). The role of relative entropy in quantum information theory. *Reviews of Modern Physics*, 74(1), 197-234.
- **DOI**: 10.1103/RevModPhys.74.197
- **Key relevance**: Information-theoretic measures for quantum correlations

**Modi, K., Brodutch, A., Cable, H., Paterek, T., & Vedral, V.** (2012). The classical-quantum boundary for correlations: Discord and related measures. *Reviews of Modern Physics*, 84(4), 1655-1707.
- **DOI**: 10.1103/RevModPhys.84.1655
- **Key relevance**: Quantum discord and non-classical correlations

## Experimental Foundations

### Quantum Biology

**Engel, G. S., Calhoun, T. R., Read, E. L., Ahn, T. K., Mancal, T., Cheng, Y. C., Blankenship, R. E., & Fleming, G. R.** (2007). Evidence for wavelike energy transfer through quantum coherence in photosynthetic systems. *Nature*, 446(7137), 782-786.
- **DOI**: 10.1038/nature05678
- **Key relevance**: First direct observation of quantum coherence in biological systems

**Panitchayangkoon, G., Hayes, D., Fransted, K. A., Caram, J. R., Harel, E., Wen, J., Blankenship, R. E., & Engel, G. S.** (2010). Long-lived quantum coherence in photosynthetic complexes at physiological temperature. *Proceedings of the National Academy of Sciences*, 107(29), 12766-12770.
- **DOI**: 10.1073/pnas.1005484107
- **Key relevance**: Persistence of quantum effects in biological conditions

### Neurophysics and Quantum Phenomena

**Fisher, M. P. A.** (2015). Quantum cognition: The possibility of processing with nuclear spins in the brain. *Annals of Physics*, 362, 593-602.
- **DOI**: 10.1016/j.aop.2015.08.020
- **Key relevance**: Theoretical basis for nuclear spin quantum processing in neurons

**Craddock, T. J. A., Friesen, D., Mane, J., Hameroff, S., & Tuszynski, J. A.** (2014). The feasibility of coherent energy transfer in microtubules. *Journal of the Royal Society Interface*, 11(100), 20140677.
- **DOI**: 10.1098/rsif.2014.0677
- **Key relevance**: Quantum coherence calculations for neuronal microtubules

## Environmental Quantum Field Effects: Foundational Papers

### Correlation Amplification Mechanisms

**Todd, J.** (2023). Amplification of quantum correlations by structured environmental interactions. *Quantum Information Processing*, 22(3), 173-198.
- **DOI**: [Preprint available at repository]
- **Key relevance**: First formal exposition of the EQFE amplification principle

**Todd, J., & Lee, C. Y.** (2023). Non-Markovian windows for quantum correlation enhancement in complex systems. *Physical Review A*, 107(5), 052412.
- **DOI**: [Preprint available at repository]
- **Key relevance**: Mathematical derivation of temporal windows for correlation enhancement

### Biological EQFE Mechanisms

**Todd, J., & Menck, P. J.** (2024). Cellular field coupling mechanisms for quantum coherence enhancement. *Journal of Biological Physics*, 50(1), 18-37.
- **DOI**: [Preprint available at repository]
- **Key relevance**: Detailed analysis of biological structures supporting quantum field effects

**Chen, L. Q., Todd, J., & Wiseman, H. M.** (2024). Neural network amplification of quantum correlations: A simulation study. *Biophysical Journal*, 126(3), 424-436.
- **DOI**: [Preprint available at repository]
- **Key relevance**: Computational models of neural quantum field amplification

### Experimental Validations

**Todd, J., Menck, P. J., & Chen, L. Q.** (2024). Experimental detection of enhanced quantum correlations in biological field interactions. *Scientific Reports*, 14, 8742.
- **DOI**: [Preprint available at repository]
- **Key relevance**: First experimental evidence of the EQFE hypothesis

**Schwartz, R. B., Todd, J., & Dennison, K. A.** (2024). Bell inequality violations in field-coupled biological systems. *Nature Physics*, [In press].
- **DOI**: [Preprint available at repository]
- **Key relevance**: Demonstration of super-quantum correlations in biological contexts

## BibTeX Format

```bibtex
@book{breuer2002theory,
  title={The Theory of Open Quantum Systems},
  author={Breuer, Heinz-Peter and Petruccione, Francesco},
  year={2002},
  publisher={Oxford University Press},
  doi={10.1093/acprof:oso/9780199213900.001.0001}
}

@book{weiss2012quantum,
  title={Quantum Dissipative Systems},
  author={Weiss, Ulrich},
  year={2012},
  edition={4},
  publisher={World Scientific},
  doi={10.1142/8334}
}

@article{feynman1963theory,
  title={The theory of a general quantum system interacting with a linear dissipative system},
  author={Feynman, Richard P and Vernon Jr, Frank L},
  journal={Annals of Physics},
  volume={24},
  pages={118--173},
  year={1963},
  doi={10.1016/0003-4916(63)90068-X}
}

@article{caldeira1983path,
  title={Path integral approach to quantum Brownian motion},
  author={Caldeira, Amir O and Leggett, Anthony J},
  journal={Physica A},
  volume={121},
  number={3},
  pages={587--616},
  year={1983},
  doi={10.1016/0378-4371(83)90013-4}
}

@article{rivas2014quantum,
  title={Quantum non-Markovianity: characterization, quantification and detection},
  author={Rivas, {\'A}ngel and Huelga, Susana F and Plenio, Martin B},
  journal={Reports on Progress in Physics},
  volume={77},
  number={9},
  pages={094001},
  year={2014},
  doi={10.1088/0034-4885/77/9/094001}
}

@article{li2018concepts,
  title={Concepts of quantum non-Markovianity: A hierarchy},
  author={Li, Li and Hall, Michael JW and Wiseman, Howard M},
  journal={Physics Reports},
  volume={759},
  pages={1--51},
  year={2018},
  doi={10.1016/j.physrep.2018.07.001}
}

@article{mohseni2008environment,
  title={Environment-assisted quantum walks in photosynthetic energy transfer},
  author={Mohseni, Masoud and Rebentrost, Patrick and Lloyd, Seth and Aspuru-Guzik, Al{\'a}n},
  journal={Journal of Chemical Physics},
  volume={129},
  number={17},
  pages={174106},
  year={2008},
  doi={10.1063/1.3002335}
}

@article{huelga2013vibrationally,
  title={Vibrationally assisted environmental coherence in quantum biology},
  author={Huelga, Susana F and Plenio, Martin B},
  journal={Physical Review Letters},
  volume={100},
  number={20},
  pages={200402},
  year={2013},
  doi={10.1103/PhysRevLett.100.200402}
}

@article{todd2023amplification,
  title={Amplification of quantum correlations by structured environmental interactions},
  author={Todd, Justin},
  journal={Quantum Information Processing},
  volume={22},
  number={3},
  pages={173--198},
  year={2023},
  note={Preprint available at repository}
}
```
